@@ -10,8 +10,6 @@ __PACKAGE__->table("employer");
 __PACKAGE__->add_columns(
   "employer_id",
   { data_type => "INTEGER", is_nullable => 0, size => 8 },
-  "user_id",
-  { data_type => "INTEGER", is_nullable => 0, size => 8 },
   "name",
   { data_type => "VARCHAR", is_nullable => 0, size => 32 },
   "category",
@@ -20,11 +18,15 @@ __PACKAGE__->add_columns(
 );
 __PACKAGE__->set_primary_key("employer_id");
 
-__PACKAGE__->belongs_to(
+__PACKAGE__->many_to_many(
+    'users' => 'user_employer',
     'user',
-    'BookDB::Schema::Result::User',
-    { user_id => 'user_id' },
 );
 
+__PACKAGE__->has_many(
+    'user_employer',
+    'BookDB::Schema::Result::UserEmployer',
+    { 'foreign.employer_id' => 'self.employer_id' },
+);
 
 1;
